(define-module (ui osec ajax)
               :use-module (alterator ajax)
               :use-module (alterator woo)
               :use-module (alterator algo)
               :use-module (alterator card-index)
               :export (init))

; Debug string (paste in for your needs).
;(format #t "XXX: ~S~%" rdp_profile_name)

; Lists
(define lists '(
                "list_periods"
                "list_logs"
                "list_path"
                ))

; Bools
(define bools '(
                "bool_write_log"
                "bool_send_mail"
                "bool_running"
                ))

; Labels
(define labels '(
                 "label_status"
                 ))

; Inputs
(define inputs '(
                 "input_rotate"
                 "input_new_path"
                 ))

; All known parameters
(define parameters (append bools
                           (append labels
                           (append inputs
                                   lists))))

; Constants
(define *update-period* 2)

; Change visibility some widgets
(define (update-widgets)
  (let* ((running (form-value "bool_running")))
      (form-update-visibility "button_stop" running)
      (form-update-visibility "button_run" (not running))))

; Fill wigets with default parameters
(define (set-default-parameters)
  (form-update-value "input_rotate" "10")
  (form-update-value "list_periods" "weekly")
  (form-update-value "bool_write_log" #t)
  (form-update-value "bool_send_mail" #f)
  )

; Read current OSEC status
(define (read-current-status)
  (format #t "[ajax] Read current status\n")
  (and
    ; Reset all values
    (for-each (lambda(p) (form-update-value p "")) parameters)

    ; Set default parameters
    (set-default-parameters)

    ; Fill all lists
    (for-each
      (lambda(lst)
        (form-update-enum lst
                          (woo-list (string-append "/osec/" lst) 'language (form-value "language")))) lists)

    ; Rebind actions on lists
    (form-bind "list_logs" "change" show-log)

    ; Read current settings
    (let read-status ((async #f))
      (let* ((settings (woo-read "/osec"
                                 'language (form-value "language"))))
        (form-update-value-list parameters settings)

        ; Update visibility same widgets
        (update-widgets)

        (if (woo-get-option (cond-car settings) 'bool_running #f)
          (form-set-timeout (lambda()
                              (read-status #t))
                            *update-period*)
          (if async (read-current-status)))))))

; Save new configuration options
(define (save-options)
  (catch/message
    (lambda()
      (apply woo-write "/osec" 'set #t
             (form-value-list
               '("list_periods" "input_rotate" "bool_write_log" "bool_send_mail")))))
  (read-current-status))

; Run osec
(define (osec-run)
  (catch/message
    (lambda()
      (woo-write "/osec" 'run "anytext")))
  (read-current-status))

; Show selected log file
(define (show-log)
  (catch/message
    (lambda ()
      (form-update-value "label_log_file_name" (form-value "list_logs"))
      (format #t "[ajax] Show log contents: ~S~%"
              (form-value "list_logs"))
      (form-update-enum "list_log_contents"
                        (woo-list "/osec/log" 'log_name (form-value "list_logs"))))))

; Stop osec
(define (osec-stop)
  (catch/message
    (lambda()
      (woo-write "/osec" 'kill "anytext")))
  (read-current-status))

; Add new watch item
(define (path-new)
  (catch/message
    (lambda()
      (format #t "[ajax] Add new path ~S~%" (form-value "input_new_path"))
      (woo-write "/osec" 'new "anytext" 'new_path (form-value "input_new_path") 'language (form-value "language"))))
  (read-current-status))

; Remove watch item
(define (path-rm)
  (catch/message
    (lambda()
      (format #t "[ajax] Selected path to remove: ~S~%" (form-value-list '("list_path")))
      (apply woo-delete "/osec/path"
             'language (form-value "language")
             (form-value-list '("list_path")))))
  (read-current-status))

; Initialization routine
(define (init)
  ; Interface initialization
  (read-current-status)
  ; Interconnect button with action
  (form-bind "button_save_options" "click" save-options)
  (form-bind "button_run" "click" osec-run)
  (form-bind "button_stop" "click" osec-stop)
  (form-bind "button_update_log_files" "click" read-current-status)
  (form-bind "button_path_new" "click" path-new)
  (form-bind "button_path_rm" "click" path-rm))

; vim: ft=lisp
